#!/APSshare/epics/base-3.14.12.4/bin/linux-x86_64/softIoc

# This is the Simulated Photon Source shutter simulator
# Created 2014-10-14 by Andrew Johnson <anj@aps.anl.gov>

# Overall control records
dbLoadRecords common.db

# Beamline simulator records
#   Note: Beamlines 4 and 13 are not active, deliberately!
dbLoadRecords shutter.db, prefix=id01
dbLoadRecords shutter.db, prefix=id02
dbLoadRecords shutter.db, prefix=id03
# dbLoadRecords shutter.db, prefix=id04
dbLoadRecords shutter.db, prefix=id05
dbLoadRecords shutter.db, prefix=id06
dbLoadRecords shutter.db, prefix=id07
dbLoadRecords shutter.db, prefix=id08
dbLoadRecords shutter.db, prefix=id09

dbLoadRecords shutter.db, prefix=id10
dbLoadRecords shutter.db, prefix=id11
dbLoadRecords shutter.db, prefix=id12
# dbLoadRecords shutter.db, prefix=id13
dbLoadRecords shutter.db, prefix=id14
dbLoadRecords shutter.db, prefix=id15
dbLoadRecords shutter.db, prefix=id16
dbLoadRecords shutter.db, prefix=id17
dbLoadRecords shutter.db, prefix=id18
dbLoadRecords shutter.db, prefix=id19

dbLoadRecords shutter.db, prefix=id20
dbLoadRecords shutter.db, prefix=id21
dbLoadRecords shutter.db, prefix=id22
dbLoadRecords shutter.db, prefix=id23
dbLoadRecords shutter.db, prefix=id24
dbLoadRecords shutter.db, prefix=id25
dbLoadRecords shutter.db, prefix=id26
dbLoadRecords shutter.db, prefix=id27
dbLoadRecords shutter.db, prefix=id28
dbLoadRecords shutter.db, prefix=id29

dbLoadRecords shutter.db, prefix=id30
dbLoadRecords shutter.db, prefix=id31
dbLoadRecords shutter.db, prefix=id32
dbLoadRecords shutter.db, prefix=id33
dbLoadRecords shutter.db, prefix=id34
dbLoadRecords shutter.db, prefix=id35
dbLoadRecords shutter.db, prefix=id36

# Any per-student records
dbLoadRecords student.db, prefix=user00
dbLoadRecords student.db, prefix=user01
dbLoadRecords student.db, prefix=user02
dbLoadRecords student.db, prefix=user03
dbLoadRecords student.db, prefix=user04
dbLoadRecords student.db, prefix=user05
dbLoadRecords student.db, prefix=user06
dbLoadRecords student.db, prefix=user07
dbLoadRecords student.db, prefix=user08
dbLoadRecords student.db, prefix=user09

dbLoadRecords student.db, prefix=user10
dbLoadRecords student.db, prefix=user11
dbLoadRecords student.db, prefix=user12
dbLoadRecords student.db, prefix=user13
dbLoadRecords student.db, prefix=user14
dbLoadRecords student.db, prefix=user15
dbLoadRecords student.db, prefix=user16
dbLoadRecords student.db, prefix=user17
dbLoadRecords student.db, prefix=user18
dbLoadRecords student.db, prefix=user19

dbLoadRecords student.db, prefix=user20
dbLoadRecords student.db, prefix=user21
dbLoadRecords student.db, prefix=user22
dbLoadRecords student.db, prefix=user23
dbLoadRecords student.db, prefix=user24
dbLoadRecords student.db, prefix=user25
dbLoadRecords student.db, prefix=user26
dbLoadRecords student.db, prefix=user27
dbLoadRecords student.db, prefix=user28
dbLoadRecords student.db, prefix=user29

dbLoadRecords student.db, prefix=user30
dbLoadRecords student.db, prefix=user31
dbLoadRecords student.db, prefix=user32
dbLoadRecords student.db, prefix=user33
dbLoadRecords student.db, prefix=user34
dbLoadRecords student.db, prefix=user35
dbLoadRecords student.db, prefix=user36
dbLoadRecords student.db, prefix=user37
dbLoadRecords student.db, prefix=user38
dbLoadRecords student.db, prefix=user39

dbLoadRecords student.db, prefix=user40
dbLoadRecords student.db, prefix=user41
dbLoadRecords student.db, prefix=user42
dbLoadRecords student.db, prefix=user43
dbLoadRecords student.db, prefix=user44
dbLoadRecords student.db, prefix=user45
dbLoadRecords student.db, prefix=user46
dbLoadRecords student.db, prefix=user47
dbLoadRecords student.db, prefix=user48
dbLoadRecords student.db, prefix=user49

dbLoadRecords student.db, prefix=user50
dbLoadRecords student.db, prefix=user51
dbLoadRecords student.db, prefix=user52
dbLoadRecords student.db, prefix=user53
dbLoadRecords student.db, prefix=user54
dbLoadRecords student.db, prefix=user55
dbLoadRecords student.db, prefix=user56
dbLoadRecords student.db, prefix=user57
dbLoadRecords student.db, prefix=user58
dbLoadRecords student.db, prefix=user59

dbLoadRecords student.db, prefix=user60
dbLoadRecords student.db, prefix=user61
dbLoadRecords student.db, prefix=user62
dbLoadRecords student.db, prefix=user63
dbLoadRecords student.db, prefix=user64
dbLoadRecords student.db, prefix=user65
dbLoadRecords student.db, prefix=user66
dbLoadRecords student.db, prefix=user67
dbLoadRecords student.db, prefix=user68
dbLoadRecords student.db, prefix=user69

dbLoadRecords student.db, prefix=user70
dbLoadRecords student.db, prefix=user71
dbLoadRecords student.db, prefix=user72
dbLoadRecords student.db, prefix=user73
dbLoadRecords student.db, prefix=user74
dbLoadRecords student.db, prefix=user75
dbLoadRecords student.db, prefix=user76
dbLoadRecords student.db, prefix=user77
dbLoadRecords student.db, prefix=user78
dbLoadRecords student.db, prefix=user79

dbLoadRecords student.db, prefix=user80
dbLoadRecords student.db, prefix=user81
dbLoadRecords student.db, prefix=user82
dbLoadRecords student.db, prefix=user83
dbLoadRecords student.db, prefix=user84
dbLoadRecords student.db, prefix=user85
dbLoadRecords student.db, prefix=user86
dbLoadRecords student.db, prefix=user87
dbLoadRecords student.db, prefix=user88
dbLoadRecords student.db, prefix=user89

dbLoadRecords student.db, prefix=user90
dbLoadRecords student.db, prefix=user91
dbLoadRecords student.db, prefix=user92
dbLoadRecords student.db, prefix=user93
dbLoadRecords student.db, prefix=user94
dbLoadRecords student.db, prefix=user95
dbLoadRecords student.db, prefix=user96
dbLoadRecords student.db, prefix=user97
dbLoadRecords student.db, prefix=user98
dbLoadRecords student.db, prefix=user99

iocInit

# After 10 seconds, turn on beam permit
epicsThreadSleep 10
dbpf SPS:permit 1

